<?php

namespace App\Dto\Output;

use ApiPlatform\Metadata\ApiProperty;
use ApiPlatform\Metadata\Get;
use App\Entity\Client;
use App\Entity\Partition;
use Symfony\Component\Serializer\Annotation\Groups;

#[Get(shortName: 'Client')]
final class ClientOutput extends AbstractOutput
{
    #[Groups(['client:read'])]
    public string $name;

    #[Groups(['client:read'])]
    public ?string $serialNumber = '';

    #[Groups(['client:read'])]
    public ?string $netiface = '';

    #[Groups(['client:read'])]
    public ?OrganizationalUnitOutput $organizationalUnit = null;

    #[Groups(['client:read'])]
    public array $partitions = [];

    #[Groups(['client:read'])]
    public ?MenuOutput $menu = null;

    #[Groups(['client:read'])]
    public ?HardwareProfileOutput $hardwareProfile = null;

    #[Groups(['client:read'])]
    public \DateTime $createdAt;

    #[Groups(['client:read'])]
    public ?string $createdBy = null;

    public function __construct(Client $client)
    {
        parent::__construct($client);

        $this->name = $client->getName();
        $this->serialNumber = $client->getSerialNumber();
        $this->netiface = $client->getNetiface();

        if ($client->getOrganizationalUnit()) {
            $this->organizationalUnit = new OrganizationalUnitOutput($client->getOrganizationalUnit());
        }

        $this->partitions = $client->getPartitions()->map(
            fn(Partition $partition) => new PartitionOutput($partition)
        )->toArray();

        $this->menu = $client->getMenu() ? new MenuOutput($client->getMenu()) : null;
        $this->hardwareProfile = $client->getHardwareProfile() ? new HardwareProfileOutput($client->getHardwareProfile()) : null;

        $this->createdAt = $client->getCreatedAt();
        $this->createdBy = $client->getCreatedBy();
    }
}